==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/MonthlyRecurrenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Monthly recurrence object.
 * @property daysOfMonth Specifies the values for monthly recurrence pattern.
 * @property endTime End time for recurrence.
 * @property recurrenceType Specifies when the recurrence should be applied.
 * Expected value is 'Monthly'.
 * @property startTime Start time for recurrence.
 */
public data class MonthlyRecurrenceArgs(
    public val daysOfMonth: Output<List<Int>>,
    public val endTime: Output<String>? = null,
    public val recurrenceType: Output<String>,
    public val startTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder()
            .daysOfMonth(daysOfMonth.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .recurrenceType(recurrenceType.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MonthlyRecurrenceArgs].
 */
@PulumiTagMarker
public class MonthlyRecurrenceArgsBuilder internal constructor() {
    private var daysOfMonth: Output<List<Int>>? = null

    private var endTime: Output<String>? = null

    private var recurrenceType: Output<String>? = null

    private var startTime: Output<String>? = null

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("ippyavhpbrlsypya")
    public suspend fun daysOfMonth(`value`: Output<List<Int>>) {
        this.daysOfMonth = value
    }

    @JvmName("jdnyejwnlqdirjnk")
    public suspend fun daysOfMonth(vararg values: Output<Int>) {
        this.daysOfMonth = Output.all(values.asList())
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("uuuytjpvtxnqkxlk")
    public suspend fun daysOfMonth(values: List<Output<Int>>) {
        this.daysOfMonth = Output.all(values)
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("rdeiryyuaturtlnf")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("opchggskmounufcr")
    public suspend fun recurrenceType(`value`: Output<String>) {
        this.recurrenceType = value
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("jryfxcaphjpsehnh")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("awutkcyxasouravt")
    public suspend fun daysOfMonth(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("dnhkgdeuvbwywdlm")
    public suspend fun daysOfMonth(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("cdcthonnefjgvrkn")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("kyqpbsmrqvkmudtb")
    public suspend fun recurrenceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recurrenceType = mapped
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("gjxprwundwxqfwyw")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    internal fun build(): MonthlyRecurrenceArgs = MonthlyRecurrenceArgs(
        daysOfMonth = daysOfMonth ?: throw PulumiNullFieldException("daysOfMonth"),
        endTime = endTime,
        recurrenceType = recurrenceType ?: throw PulumiNullFieldException("recurrenceType"),
        startTime = startTime,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/MonthlyRecurrenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Monthly recurrence object.
 * @property daysOfMonth Specifies the values for monthly recurrence pattern.
 * @property endTime End time for recurrence.
 * @property recurrenceType Specifies when the recurrence should be applied.
 * Expected value is 'Monthly'.
 * @property startTime Start time for recurrence.
 */
public data class MonthlyRecurrenceArgs(
    public val daysOfMonth: Output<List<Int>>,
    public val endTime: Output<String>? = null,
    public val recurrenceType: Output<String>,
    public val startTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.MonthlyRecurrenceArgs.builder()
            .daysOfMonth(daysOfMonth.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .recurrenceType(recurrenceType.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MonthlyRecurrenceArgs].
 */
@PulumiTagMarker
public class MonthlyRecurrenceArgsBuilder internal constructor() {
    private var daysOfMonth: Output<List<Int>>? = null

    private var endTime: Output<String>? = null

    private var recurrenceType: Output<String>? = null

    private var startTime: Output<String>? = null

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("difioiaqsgngxcey")
    public suspend fun daysOfMonth(`value`: Output<List<Int>>) {
        this.daysOfMonth = value
    }

    @JvmName("snokunhgulqxxxfl")
    public suspend fun daysOfMonth(vararg values: Output<Int>) {
        this.daysOfMonth = Output.all(values.asList())
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("jfijtbeohkmbxxab")
    public suspend fun daysOfMonth(values: List<Output<Int>>) {
        this.daysOfMonth = Output.all(values)
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("awtiaswhfjoqwciu")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("lwmoaqbfdawrbmvy")
    public suspend fun recurrenceType(`value`: Output<String>) {
        this.recurrenceType = value
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("peytjlwtpmygqsvh")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Specifies the values for monthly recurrence pattern.
     */
    @JvmName("lxrgwiipjuopdjho")
    public suspend fun daysOfMonth(`value`: List<Int>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param values Specifies the values for monthly recurrence pattern.
     */
    @JvmName("pgksaeamgrwgemwn")
    public suspend fun daysOfMonth(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.daysOfMonth = mapped
    }

    /**
     * @param value End time for recurrence.
     */
    @JvmName("mpobhhqiofxrsmdr")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value Specifies when the recurrence should be applied.
     * Expected value is 'Monthly'.
     */
    @JvmName("pbjfmbmaungwiexe")
    public suspend fun recurrenceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recurrenceType = mapped
    }

    /**
     * @param value Start time for recurrence.
     */
    @JvmName("wymknhxytrrymvrd")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    internal fun build(): MonthlyRecurrenceArgs = MonthlyRecurrenceArgs(
        daysOfMonth = daysOfMonth ?: throw PulumiNullFieldException("daysOfMonth"),
        endTime = endTime,
        recurrenceType = recurrenceType ?: throw PulumiNullFieldException("recurrenceType"),
        startTime = startTime,
    )
}
